<?php
/*
Plugin Name: TheChatPress.com
Plugin URI: https://thechatpress.com/
Description: An AI Assistant built on top of TheChatPress SaaS. Installs easily with one button to generate your AI Agent for your site.
Version: 1.1.0
Author: The Chat Press Team
License: GPL2
Text Domain: thechatpress
*/

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Prevent direct access
}

/** 
 * 1. Define constants
 */
define( 'THECHATPRESS_OPTION_BUSINESS_OWNER_UUID', 'thechatpress_business_owner_uuid' );
define( 'THECHATPRESS_OPTION_GENERAL_UUID',        'thechatpress_general_uuid' );
define( 'THECHATPRESS_SAVE_CONFIG_ENDPOINT', 'https://zentesimal-prod-3f53e5c5464b.herokuapp.com/save_configuration' );

/**
 * 2. Admin Menu: "TheChatPress" top-level page
 */
add_action( 'admin_menu', 'thechatpress_register_admin_menu' );
function thechatpress_register_admin_menu() {
    add_menu_page(
        'TheChatPress.com',
        'TheChatPress',
        'manage_options',
        'thechatpress-settings',
        'thechatpress_admin_page_render',
        'dashicons-format-chat',
        59
    );
}

/**
 * 3. Render the Admin Page
 */
function thechatpress_admin_page_render() {
    if ( ! current_user_can( 'manage_options' ) ) {
        return;
    }

    // If user clicked "Generate and Inject Code"
    if ( isset( $_POST['thechatpress_generate'] ) && check_admin_referer( 'thechatpress_generate_action', 'thechatpress_generate_nonce' ) ) {
        thechatpress_generate_and_inject_code();
    }

    // If user clicked "Recreate / Reset"
    if ( isset( $_POST['thechatpress_reset'] ) && check_admin_referer( 'thechatpress_reset_action', 'thechatpress_reset_nonce' ) ) {
        thechatpress_reset_code();
        add_settings_error(
            'thechatpress_messages',
            'thechatpress_reset',
            __( 'Account was erased. You can now regenerate.', 'thechatpress' ),
            'warning'
        );
    }

    // Show admin notices (error or success messages)
    settings_errors( 'thechatpress_messages' );

    // Retrieve current stored values
    $business_owner_uuid = get_option( THECHATPRESS_OPTION_BUSINESS_OWNER_UUID );
    $general_uuid        = get_option( THECHATPRESS_OPTION_GENERAL_UUID );

    ?>
    <div class="wrap">
        <h1><?php esc_html_e( 'TheChatPress.com Setup', 'thechatpress' ); ?></h1>
        <hr style="margin-bottom: 20px;">

        <!-- Section: Account Details -->
        <h2><?php esc_html_e( 'Account Details', 'thechatpress' ); ?></h2>
        <?php if ( $business_owner_uuid && $general_uuid ) : ?>
            <p><strong><?php esc_html_e( 'Account UUID:', 'thechatpress' ); ?></strong> <?php echo esc_html( $business_owner_uuid ); ?></p>
            <p><strong><?php esc_html_e( 'Settings Link:', 'thechatpress' ); ?></strong><br/>
                <a href="http://app.thechatpress.com/settings?businessOwnerUUID=<?php echo urlencode( $business_owner_uuid ); ?>" target="_blank">
                    <?php echo esc_url( 'http://app.thechatpress.com/settings?businessOwnerUUID=' . urlencode( $business_owner_uuid ) ); ?>
                </a>
            </p>
            <p style="color: red;">
                <strong><?php esc_html_e( 'Warning:', 'thechatpress' ); ?></strong>
                <?php esc_html_e( 'You already have an account with an Assistant configured. If you click "Reset" below, you will erase it. This may break existing integration.', 'thechatpress' ); ?>
            </p>
            <form method="post" style="margin-top: 10px;">
                <?php wp_nonce_field( 'thechatpress_reset_action', 'thechatpress_reset_nonce' ); ?>
                <input type="submit" class="button button-secondary" name="thechatpress_reset" value="<?php esc_attr_e( 'Recreate Account', 'thechatpress' ); ?>">
            </form>
        <?php else : ?>
            <p><?php esc_html_e( 'No account or AI assistants found.', 'thechatpress' ); ?></p>
            <p><?php esc_html_e( 'Click the button below to generate your account and your first AI assistant.', 'thechatpress' ); ?></p>
            <form method="post" style="margin-top: 10px;">
                <?php wp_nonce_field( 'thechatpress_generate_action', 'thechatpress_generate_nonce' ); ?>
                <input type="submit" class="button button-primary" name="thechatpress_generate" value="<?php esc_attr_e( 'Generate AI Assistant', 'thechatpress' ); ?>">
            </form>
        <?php endif; ?>
        <hr style="margin: 30px 0;">

        <!-- Section: Help and Support -->
        <h2><?php esc_html_e( 'Help and Support', 'thechatpress' ); ?></h2>
        <p>
            <?php esc_html_e( 'If you encounter any issues or have suggestions, feel free to contact us:', 'thechatpress' ); ?>
            <br>
            <a href="mailto:hello@thechatpress.com"><?php esc_html_e( 'hello@thechatpress.com', 'thechatpress' ); ?></a>
            <?php esc_html_e( 'or through the chatbot on', 'thechatpress' ); ?>
            <a href="https://thechatpress.com" target="_blank"><?php esc_html_e( 'thechatpress.com', 'thechatpress' ); ?></a>.
        </p>

        <hr style="margin: 30px 0;">

        <!-- Section: Pricing -->
        <h2><?php esc_html_e( 'Pricing', 'thechatpress' ); ?></h2>
        <p><?php esc_html_e( 'TheChatPress is free to use for the first few dozen conversations. For continued usage, we recommend one of our affordable plans:', 'thechatpress' ); ?></p>
        <ul style="list-style: disc; padding-left: 20px;">
            <li>
                <a href="https://buy.stripe.com/cN25m3270g53dMsbIV" target="_blank"><?php esc_html_e( 'Basic: $5/month', 'thechatpress' ); ?></a>
            </li>
            <li>
                <a href="https://buy.stripe.com/7sI01J7rk065dMsfZ9" target="_blank"><?php esc_html_e( 'Pro: $7/month', 'thechatpress' ); ?></a>
            </li>
        </ul>
    </div>
    <?php
}

/**
 * 4. Generate & Inject Code
 *    - Generates two UUIDs
 *    - Calls the external API
 *    - Builds + saves the snippet
 */
function thechatpress_generate_and_inject_code() {

    // 4.1 Generate two UUIDs
    $business_owner_uuid = wp_generate_uuid4();
    $general_uuid        = wp_generate_uuid4();

    // 4.2 Build the JSON body for the external POST request
    $body = array(
        'businessOwnerUUID' => $business_owner_uuid,
        'ctaColor'          => '#000000',
        'ctaShape'          => 'extended',
        'ctaText'           => '',
        'additionalInfo'    => '',
        'tone'              => 3,
        'responseLength'    => 3,
        'website'           => '',
        'selectedChannel'   => null,
        'channelInfo'       => new stdClass(),
        'websites' => array( get_site_url() ),
        'additionalNotes'   => new stdClass(),
        'handoverUnknown'   => true,
        'selectedChannels'  => array(),
        'reasons'           => array(),
        'disabledUrls'      => array(),
        'uuid'              => $general_uuid,
    );

    // 4.3 Send the POST request
    $response = wp_remote_post(
        THECHATPRESS_SAVE_CONFIG_ENDPOINT,
        array(
            'headers' => array(
                'Content-Type' => 'application/json',
            ),
            'body'    => wp_json_encode( $body ),
            'timeout' => 20,
        )
    );

    // 4.4 Check for errors
    if ( is_wp_error( $response ) ) {
        $error_message = $response->get_error_message();
        add_settings_error(
            'thechatpress_messages',
            'thechatpress_api_error',
            'Remote request failed: ' . esc_html( $error_message ),
            'error'
        );
        return;
    }

    $status_code = wp_remote_retrieve_response_code( $response );
    if ( $status_code < 200 || $status_code > 299 ) {
        $resp_body = wp_remote_retrieve_body( $response );
        add_settings_error(
            'thechatpress_messages',
            'thechatpress_api_status',
            "Remote request returned status {$status_code}. Body: " . esc_html( $resp_body ),
            'error'
        );
        return;
    }

    // 4.6 Save to the WP database
    update_option( THECHATPRESS_OPTION_BUSINESS_OWNER_UUID, $business_owner_uuid );
    update_option( THECHATPRESS_OPTION_GENERAL_UUID,        $general_uuid );

    // 4.7 Add a success message
    add_settings_error(
        'thechatpress_messages',
        'thechatpress_generated',
        'Code generated and injected successfully!',
        'updated'
    );
}

function thechatpress_enqueue_scripts() {
    $general_uuid = get_option( THECHATPRESS_OPTION_GENERAL_UUID );

    if ( empty( $general_uuid ) ) {
        return;
    }

    $timestamp = time();

    $script_url = add_query_arg(
        array(
            'uuid' => $general_uuid,
            't'    => $timestamp,
        ),
        'https://assistant.thechatpress.com/chat-widget.min.js'
    );

    if ( ! wp_script_is( 'thechatpress-widget', 'enqueued' ) ) {
        wp_register_script(
            'thechatpress-widget',
            $script_url,
            array(),
            '1.1.0',
            true
        );
        wp_enqueue_script( 'thechatpress-widget' );
    }
}

add_action( 'wp_enqueue_scripts', 'thechatpress_enqueue_scripts' );

/**
 * 5. Reset / erase code from the database
 */
function thechatpress_reset_code() {
    delete_option( THECHATPRESS_OPTION_BUSINESS_OWNER_UUID );
    delete_option( THECHATPRESS_OPTION_GENERAL_UUID );
}